Crate datalove_datafun_parser

Crate datalove_datafun_parser 

Datafun parser module.

Parses datafun source text into AST nodes.

Functions

datafun_spans
Extract datafun expression spans from a parsed source.
module_spans
The spans of one module, in the form diagnostics look things up in.
parse
Parse a Source into a datafun script with span information.
parse_expr
Parse a Source as a single expression.
parse_for_diagnostics
Public tracked wrapper for integration code to enable diagnostic accumulation.
parse_for_test
Tracked wrapper for parser tests that only need the ParsedStatements.
parse_integration_test
Public tracked wrapper for integration tests that returns just the ParsedStatements.
parse_module_ast
Parse a module and return just its statements.
parse_module_full
Parse a module and return its statements and spans together.
parse_with_module_id
Parse a Source into a datafun script with span information and module context.