pub fn parse<'db>(db: &'db dyn Db, source: Source) -> &'db ParseResult<'db>Expand description
Parse a Source into a datafun script with span information.
For script parsing (no module context).
pub fn parse<'db>(db: &'db dyn Db, source: Source) -> &'db ParseResult<'db>Parse a Source into a datafun script with span information.
For script parsing (no module context).