parse_for_diagnostics

Function parse_for_diagnostics 

pub fn parse_for_diagnostics<'db>(
    db: &'db dyn Db,
    source: Source,
) -> &'db ParsedStatements<'db>
Public tracked wrapper for integration code to enable diagnostic accumulation.

This function should be called before parse() to accumulate diagnostics, then parse() can be called separately to get the full ParseResult. Returns just the ParsedStatements to satisfy Salsa’s type requirements.