pub fn parse_for_test<'db>(
db: &'db dyn Db,
source: Source,
) -> &'db ParsedStatements<'db>Expand description
Tracked wrapper for parser tests that only need the ParsedStatements.
pub fn parse_for_test<'db>(
db: &'db dyn Db,
source: Source,
) -> &'db ParsedStatements<'db>Tracked wrapper for parser tests that only need the ParsedStatements.