parse_integration_test

Function parse_integration_test 

pub fn parse_integration_test<'db>(
    db: &'db dyn Db,
    source: Source,
) -> &'db ParsedStatements<'db>
Public tracked wrapper for integration tests that returns just the ParsedStatements.

Integration tests are compiled as separate binaries and need pub access.