parse_with_module_id

Function parse_with_module_id 

pub fn parse_with_module_id<'db>(
    db: &'db dyn Db,
    source: Source,
    module_id: Option<ModuleId<'db>>,
) -> ParseResult<'db>
Parse a Source into a datafun script with span information and module context.

The module_id is used to give functions stable identity for memoization.