Datafun parser module.
Parses datafun source text into AST nodes.
Functions
- datafun_
spans - Extract datafun expression spans from a parsed source.
- module_
spans - The spans of one module, in the form diagnostics look things up in.
- parse
- Parse a Source into a datafun script with span information.
- parse_
expr - Parse a Source as a single expression.
- parse_
for_ diagnostics - Public tracked wrapper for integration code to enable diagnostic accumulation.
- parse_
for_ test - Tracked wrapper for parser tests that only need the ParsedStatements.
- parse_
integration_ test - Public tracked wrapper for integration tests that returns just the ParsedStatements.
- parse_
module_ ast - Parse a module and return just its statements.
- parse_
module_ full - Parse a module and return its statements and spans together.
- parse_
with_ module_ id - Parse a Source into a datafun script with span information and module context.